@@ -235,9 +235,9 @@ def validate_user(account_code, username, password):
     hashed_password = hash_password(password)
     return validate_admin(account_code, username, hashed_password) or validate_projectManager(account_code, username, hashed_password)
 
-def insert_document(uploadDate, filename, extension, phase, uri, nPages, tagged, training, dataset_id, uploadMethod_id):
-	query = f'INSERT INTO neuralplatform_document(uploadDate, name, extension, phase, uri, nPages, tagged, training, dataset_id, uploadMethod_id) ' + \
-			f'VALUES ("{uploadDate}", "{filename}", "{extension}", "{phase}", "{uri}", {nPages}, {tagged}, {training}, {dataset_id}, {uploadMethod_id});'
+def insert_document(uploadDate, filename, extension, phase, uri, nPages, training, dataset_id, uploadMethod_id, project_id):
+	query = f'INSERT INTO neuralplatform_document(uploadDate, name, extension, phase, uri, nPages, training, dataset_id, uploadMethod_id, project_id) ' + \
+			f'VALUES ("{uploadDate}", "{filename}", "{extension}", "{phase}", "{uri}", {nPages}, {training}, {dataset_id}, {uploadMethod_id}, {project_id});'
 	return run_insert(query)
 
 def insert_request(phase, requestDate, document_id, project_id):
@@ -272,9 +272,9 @@ def classify_page(page_id, class_id):
     run_insert(f"INSERT INTO neuralplatform_classification(classDefinition_id, page_id) VALUES ({class_id}, {page_id});")
     update_object_by_key('page', 'id', page_id, {'tagged': True})
 
-def insert_manualStep(startTime, result, request_id):
-    query = f'INSERT INTO neuralplatform_manualstep(startTime, beingTagged, completed, result, request_id) ' + \
-            f'VALUES ("{startTime}", 0, 0, "{result}", {request_id});'
+def insert_manualStep(result, request_id):
+    query = f'INSERT INTO neuralplatform_manualstep(beingTagged, completed, result, request_id) ' + \
+            f'VALUES (0, 0, "{result}", {request_id});'
     return run_insert(query)
 
 ######## DEPRECATED ########
